.. Color profiles for Sphinx.
.. Has to be used with hacks.css (bitbucket.org/lbesson/web-sphinx/src/master/.static/hacks.css)
.. role:: black
.. role:: gray
.. role:: grey
.. role:: silver
.. role:: white
.. role:: maroon
.. role:: red
.. role:: magenta
.. role:: fuchsia
.. role:: pink
.. role:: orange
.. role:: yellow
.. role:: lime
.. role:: green
.. role:: olive
.. role:: teal
.. role:: cyan
.. role:: aqua
.. role:: blue
.. role:: navy
.. role:: purple

.. role:: under
.. role:: over
.. role:: blink
.. role:: line
.. role:: strike

.. role:: it
.. role:: ob

.. role:: small
.. role:: large

.. role:: center
.. role:: left
.. role:: right


.. (c) Lilian Besson, 2011-2016, https://bitbucket.org/lbesson/web-sphinx/
